
#ifndef _C14_re663_
#define _C14_re663_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F612_3168(EIF_REFERENCE);
extern void EIF_Minit663(void);
extern EIF_INTEGER_32 F688_3634(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
